@@ -1,6 +1,10 @@
 from __future__ import absolute_import
 
+from .__about__ import __version__
+
+# Should import backend before importing anything else
 from . import backend
+
 from . import boundary_conditions as bc
 from . import callbacks
 from . import data
@@ -20,7 +24,6 @@ from .utils import apply
 
 
 __all__ = [
-    "backend",
     "bc",
     "callbacks",
     "data",
